==> apache-karaf-4.1.7-src.zip: apache-karaf-4.1.7/shell/core/src/main/java/org/apache/karaf/shell/impl/console/commands/help/SimpleHelpProvider.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.shell.impl.console.commands.help;

import java.util.HashMap;
import java.util.Map;

import org.apache.karaf.shell.api.console.Session;


public class SimpleHelpProvider implements HelpProvider {

    private final Map<String, String> help;

    public SimpleHelpProvider() {
        help = new HashMap<String, String>();
        help.put("%root%", "${command-list|}");
        help.put("all", "${command-list|}");
    }

    public String getHelp(Session session, String path) {
        if (path.indexOf('|') > 0) {
            if (path.startsWith("simple|")) {
                path = path.substring("simple|".length());
            } else {
                return null;
            }
        }
        return help.get(path);
    }

}

==> apache-karaf-4.4.9-src.zip: apache-karaf-4.4.9/shell/core/src/main/java/org/apache/karaf/shell/impl/console/commands/help/SimpleHelpProvider.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.shell.impl.console.commands.help;

import java.util.HashMap;
import java.util.Map;

import org.apache.karaf.shell.api.console.Session;


public class SimpleHelpProvider implements HelpProvider {

    private final Map<String, String> help;

    public SimpleHelpProvider() {
        help = new HashMap<>();
        help.put("%root%", "${command-list|}");
        help.put("all", "${command-list|}");
    }

    public String getHelp(Session session, String path) {
        if (path.indexOf('|') > 0) {
            if (path.startsWith("simple|")) {
                path = path.substring("simple|".length());
            } else {
                return null;
            }
        }
        return help.get(path);
    }

}
